Ths is a component of the [BUILD SI](https://computing.llnl.gov/projects/build) project where we aim to:

1. develop models of application binary interface compatibility
2. perform "splices" across binaries and libraries using spack
3. for each splice, make a prediction with some model if the binary will still work
4. test the actual spliced binary to validate the prediction.

For more details about this small pipeline, see the [buildsi/spack-splices](https://github.com/buildsi/spack-splices) and [spack-monitor-analysis](https://github.com/buildsi/spack-monitor-analysis/) repositories.